Crate tectonic_bridge_harfbuzz

Crate tectonic_bridge_harfbuzz 

This crate exists to export the Harfbuzz C/C++ API into the Cargo framework, as well as provide bindings to other tectonic crates.

Modules

ot
OpenType layout support for Harfbuzz

Structs

Blob
Blob of binary data. Facilitates interaction of program blobs (such as static memory or Vec) with the Harfbuzz library’s lifecycle management.
Buffer
Container for text and associated properties before shaping, then glyphs and associated information after shaping.
BufferMut
A borrowed mutable reference to a Buffer
BufferRef
A borrowed reference to a Buffer
Face
A typographic face - a typeface combined with a style, loaded from a binary blob. Not yet associated with a size or variation. See Font.
FaceMut
A borrowed mutable reference to a Face
FaceRef
A borrowed reference to a Face
Feature
Font
A Face that has been associated with a specific size and, possibly, variation. Ready for use in shaping.
FontFuncs
A font function table. These functions allow in-depth customization of glyph shaping for a font. The T parameter represents user-provided data when the functions are linked to a font, that will be passed to each function and thus be used as part of generating the result value.
FontFuncsMut
A borrowed mutable reference to a FontFuncs
FontFuncsRef
A borrowed reference to a FontFuncs
FontMut
A borrowed mutable reference to a Font
FontRef
A borrowed reference to a Font
GlyphExtents
GlyphInfo
GlyphPosition
ImmutFontFuncs
An immutable FontFuncs variant. This allows the value to become Send and Sync (assuming T is Send and Sync), as it may no longer be mutated by any other caller.
Language
Data type representing BCP 47 language tags
Script
Data type representing different script values
SegmentProperties
ShapePlan
A shaping plan, information about how Harfbuzz will shape a text segment based on the segment’s properties.
ShapePlanMut
A borrowed mutable reference to a ShapePlan
ShapePlanRef
A borrowed reference to a ShapePlan
Tag
Tag identifiers - used to identify tables, scripts, etc.

Enums

BufferContentType
Direction
GTag
Valid tags for use in OpenType layout-related methods
MemoryMode

Type Aliases

Codepoint
OtNameId
Position