This crate exists to export the Harfbuzz C/C++ API into the Cargo framework, as well as provide bindings to other tectonic crates.
Modules
- ot
- OpenType layout support for Harfbuzz
Structs
- Blob
- Blob of binary data. Facilitates interaction of program blobs (such as static memory or
Vec) with the Harfbuzz library’s lifecycle management. - Buffer
- Container for text and associated properties before shaping, then glyphs and associated information after shaping.
- Buffer
Mut - A borrowed mutable reference to a
Buffer - Buffer
Ref - A borrowed reference to a
Buffer - Face
- A typographic face - a typeface combined with a style, loaded from a binary blob. Not yet
associated with a size or variation. See
Font. - FaceMut
- A borrowed mutable reference to a
Face - FaceRef
- A borrowed reference to a
Face - Feature
- Font
- A
Facethat has been associated with a specific size and, possibly, variation. Ready for use in shaping. - Font
Funcs - A font function table. These functions allow in-depth customization of glyph shaping for a font.
The
Tparameter represents user-provided data when the functions are linked to a font, that will be passed to each function and thus be used as part of generating the result value. - Font
Funcs Mut - A borrowed mutable reference to a
FontFuncs - Font
Funcs Ref - A borrowed reference to a
FontFuncs - FontMut
- A borrowed mutable reference to a
Font - FontRef
- A borrowed reference to a
Font - Glyph
Extents - Glyph
Info - Glyph
Position - Immut
Font Funcs - An immutable
FontFuncsvariant. This allows the value to becomeSendandSync(assuming T isSendandSync), as it may no longer be mutated by any other caller. - Language
- Data type representing BCP 47 language tags
- Script
- Data type representing different script values
- Segment
Properties - Shape
Plan - A shaping plan, information about how Harfbuzz will shape a text segment based on the segment’s properties.
- Shape
Plan Mut - A borrowed mutable reference to a
ShapePlan - Shape
Plan Ref - A borrowed reference to a
ShapePlan - Tag
- Tag identifiers - used to identify tables, scripts, etc.
Enums
- Buffer
Content Type - Direction
- GTag
- Valid tags for use in OpenType layout-related methods
- Memory
Mode